#!/usr/bin/php
<?php
require_once __DIR__ .'/log4php/Logger.php';
require_once __DIR__ .'/SubscriptionBilling.php';

date_default_timezone_set('UTC');
set_error_handler('SubscriptionBilling::exceptionErrorHandler');

$logger = null;

try {
	Logger::configure(__DIR__ . "/log4php/config.xml");
	$logger = Logger::getLogger(__CLASS__);
		
	if ($argc < 2 || in_array($argv[1], array('--help', '-help', '-h', '-?'))) {
		echo "Usage: $argv[0] configFile [billingDate] \n\n";
		echo "billingDate : eg 2016-01-01 \n";
		exit;
	}
		
	$fileInfo = new \SplFileInfo($argv[1]);
	
	if(!$fileInfo->isFile() || !$fileInfo->isReadable()) {
		throw new \Exception("File not available");
	}
	
	$billingParameters = json_decode(file_get_contents($fileInfo->getRealPath()));
	
	if (json_last_error() !== JSON_ERROR_NONE) {
		throw new \Exception("File does not contain valid json data");
	}
	
	$billingDate = new DateTime();
	
	if($argc > 2) {
		$billingDate = new DateTime($argv[2]);
	}
	
	if(!isset($billingParameters->password)) {
		echo 'password:';
		system('stty -echo'); //Stop terminal from echoing standard in, ie hide password input
		$billingParameters->password = fgets(STDIN);
		system('stty echo');
	}
	
	//var_dump($billingDate);
	//var_dump($billingParameters);
	//exit ;
	
	$biller = new SubscriptionBilling($billingParameters);
	
	// For the list of administration units and supported billing algorithms, bill their eligible subscriptions
	foreach ($billingParameters->administrationUnitIds as $administrationUnitId) {
		foreach ($billingParameters->billingAlgorithms as $billingAlgorithm) {
			try {
				$biller->createSubscriptionPeriods($administrationUnitId, $billingDate, $billingAlgorithm);
			} catch (Exception $e1) {
				$logger->error("Uncaught Exception ".
					'[message:'.$e1->getMessage().']'.
					'[billingDate:'.(isset($billingDate) ? $billingDate : null) .']'.
					'[administrationUnitId:'.(isset($administrationUnitId) ? $administrationUnitId : null) .']'.
					'[billingAlgorithm:'.(isset($billingAlgorithmId) ? $billingAlgorithmId : null) .']', $e1);
			}
		}
	}

} catch (Exception $e) {
	$logger->fatal("Uncaught Exception: ".$e->getMessage()."\n",$e);
	exit(1);
}
?>