<?php
require_once __DIR__ .'/../log4php/Logger.php';
require_once __DIR__ .'/../omsservice/SubscriptionBillingClientService.php';

abstract class BillingAlgorithmProcessor {
	protected $logger;
	protected $omsWebService; // oms soap api
	
	function __construct(\omsservice\SubscriptionBillingClientService $omsWebService) {
		$this->logger = Logger::getLogger(__CLASS__);
		
		if(!isset($omsWebService)) {
			throw new Exception("Cannot initialize billing algorithm processor: oms soap api not specified");
		}
		
		$this->omsWebService = $omsWebService;
	}
		
	/**
	 * Calculate a potential subscription period from the subscription renewal billing context
	 * @abstract
	 * @access public
	 * @param \omsservice\subscriptionRenewalPlusBillingContextTO $subscriptionRenewalBillingContext
	 * @return \omsservice\subscriptionPeriodCreateRequestTO
	 * @throws Exception
	 */
	abstract public function calculatePotentialSubscriptionPeriod(\omsservice\subscriptionRenewalPlusBillingContextTO $subscriptionRenewalBillingContext);
}
?>