<?php
require_once __DIR__ .'/SubscriptionBilling.php';
require_once __DIR__ .'/log4php/Logger.php';

date_default_timezone_set('America/Adak');
set_error_handler('SubscriptionBilling::exceptionErrorHandler');

$logger = null;

//Oms soap connection parameters
$username = 'oms';
$password;
#$omsServiceUrl = 'http://localhost:8080/OmsApplication/apis/soap/subscriptionbilling';
$omsServiceUrl = 'https://oms.economicoutlook.net/acwa/apis/soap/subscriptionbilling';

//Billing parameters
$billingDate = new DateTime();
//$billingDate->add(new DateInterval('P1M'));
//$billingDate->sub(new DateInterval('P1M'));

$billableAdministrationUnitIds = array('79fe5baa-6489-4e6a-85da-773b30910603');
$supportedBillingAlgorithmIds = array('QUOTED_FEE', 'FIXED_FEE');

try {
	Logger::configure(__DIR__ . "/log4php/config.xml");
	$logger = Logger::getLogger(__CLASS__);

	if(!isset($password)) {
		echo 'password:';
		system('stty -echo'); //Stop terminal from echoing standard in, ie hide password input
		$password = fgets(STDIN);
		system('stty echo');
	}
	
	$biller = new SubscriptionBilling($username, $password, $omsServiceUrl);
	
	//$biller->createSubscriptionPeriod('0472eb56-532a-4471-9da4-872f614c2047', new DateTime('2015-11-20'));
	
	// For the list of administration units and supported billing algorithms, bill their eligible subscriptions
	foreach ($billableAdministrationUnitIds as $administrationUnitId) {
		foreach ($supportedBillingAlgorithmIds as $billingAlgorithmId) {
			try {
				$biller->createSubscriptionPeriods($administrationUnitId, $billingDate, $billingAlgorithmId);	
			} catch (Exception $e1) {
				$logger->error("Uncaught Exception ".
				'[message:'.$e1->getMessage().']'.
				'[administrationUnitId:'.(isset($administrationUnitId) ? $administrationUnitId : null) .']'.
				'[billingDate:'.(isset($billingDate) ? $billingDate : null) .']'.
				'[billingAlgorithmId:'.(isset($billingAlgorithmId) ? $billingAlgorithmId : null) .']', $e1);
			}
		}
	}
} catch (Exception $e2) {
	if($logger !== null) {
		$logger->fatal("Uncaught Exception: ".$e2->getMessage()."\n",$e2);
	}
	exit(1);
}
?>
